# `relationalai.Producer.__rsub__()`

```python
relationalai.Producer.__rsub__(other: Any) -> Expression
```

Returns an [`Expression`](../Expression.md) that produces the difference between the [`Producer`](./README.md) values and `other`.
`.__rsub__()` is implemented so that you may use a non-`Producer` object as the left operand.

## See Also

[`Producer.__sub__()`](./mul__.md)
